# Spam-Botz
<p align="center">
    <img src="https://i.ibb.co/LtzC9DM/Logo.png" alt="Logo" border="0">
    <br>A simple and easy to use Spam Bot
</p>

## Table of Contents

- [Motivation](#Motivation)
- [Usage](#Usage)
- [Contributing](#Contributing)
- [License](#License)

## Motivation

This application was built to well, spam. 

There is no real motivation behind building a spam bot but to simply annoy people.<br>
Or at times even crash the application. 

This application allows you to spam in variations, like : 
- Spamming a fixed static message.
- Spamming random words from a dictionary.
- Sending sequences of numbers.
- Randomly spamming large numbers.
- Good old Rage spam, but this time without breaking your keyboard.

## Usage

For the latest Stable version, go to <a href="https://github.com/SVijayB/Spam-Botz/releases">Releases</a>

Extract the files and run `Spam_botz.py` file present in the `src` folder.

As an alternative, you could also clone the repository using.
<pre>
git clone https://github.com/SVijayB/Spam-Botz.git
</pre>

**NOTE :** It is best to open your messaging window before launching `Spam_botz.py`.

**NOTE :** Make sure your cursor is pointing to the correct text box after you set your preferences.
You have only **15 Seconds** before the automation process begins.

Sometimes you might get banned from the server for spamming too many messages in a short period. To avoid this,
This application has a custom time delay feature. Make sure you enter the appropriate value.

## Contributing 

To contribute to Spam-Botz, fork the repository, create a new branch and send us a pull request. Make sure you read [CONTRIBUTING.md](https://github.com/SVijayB/Spam-Botz/blob/master/docs/CONTRIBUTING.md) before sending us Pull requests. 

Also, thanks for contributing to Open-source!

## License 

Spam-Botz is Licensed under MIT. Read the [LICENSE](https://github.com/SVijayB/Spam-Botz/blob/master/LICENSE) file for more information